Skip to contents

Friedman Seasonality Test

Usage

seasonality_friedman(data, period = NA, nyears = 0)

Arguments

data

the input data.

period

Tested periodicity. Can be missing if the input is a time series

nyears

Number of periods or number of cycles considered in the test, at the end of the series: in periods (positive value) or years (negative values). By default (nyears = 0), the entire sample is used.

Value

A c("JD3_TEST", "JD3") object (see statisticaltest() for details).

Details

Non parametric test ("ANOVA"-type).

Examples

s <- do_stationary(log(ABS$X0.2.09.10.M))$ddata
#> Error in .jcheck(): java.lang.NoClassDefFoundError: Could not initialize class jdplus.toolkit.base.protobuf.modelling.ModellingProtos$StationaryTransformation
seasonality_friedman(s)
#> Error: object 's' not found
seasonality_friedman(random_t(2, 1000), 12)
#> Value: 5.84152 
#> P-Value: 0.8837