QS (seasonal Ljung-Box) test.
Arguments
- data
the input data.
- period
Tested periodicity. Can be missing if the input is a time series
- nyears
Number of periods or number of cycles considered in the test, at the end of the series: in periods (positive value) or years (negative values). By default (
nyears = 0), the entire sample is used.- type
1 for positive autocorrelations, -1 for negative autocorrelations, 0 for all autocorrelations. By default (
type = 1)
Value
A c("JD3_TEST", "JD3") object (see statisticaltest() for details).
Examples
s <- do_stationary(log(ABS$X0.2.09.10.M))$ddata
#> Error in .jcheck(): java.lang.NoClassDefFoundError: Could not initialize class jdplus.toolkit.base.protobuf.modelling.ModellingProtos$StationaryTransformation
seasonality_qs(s)
#> Error: object 's' not found
seasonality_qs(random_t(2, 1000), 7)
#> Value: 2.266338
#> P-Value: 0.3220