More specifically, put all the noise of the components in one dedicated component
Arguments
- ucm
An UCARIMA model returned by
ucarima_model().- cmp
Index of the component that will contain the noises; 0 if a new component with all the noises will be added to the model
- adjust
If TRUE, some noise could be added to the model to ensure that all the components has positive (pseudo-)spectrum
Examples
mod1 <- arima_model("trend", delta = c(1, -2, 1))
mod2 <- arima_model("noise", variance = 1600)
hp <- ucarima_model(components = list(mod1, mod2))
#> Error in .jcheck(): java.lang.NoClassDefFoundError: Could not initialize class jdplus.toolkit.base.protobuf.modelling.ModellingProtos$ArimaModel
hpc <- ucarima_canonical(hp, cmp = 2)
#> Error: object 'hp' not found