Function allowing to include calendars and external regressors in a format
that makes them usable in an estimation process (Reg-ARIMA or Tramo
modelling, stand alone or as pre-processing in seasonal adjustment).
The regressors can be created with functions available in the package or
come from any other source, provided they are ts class objects.
References
More information on auxiliary variables in JDemetra+ online documentation: https://doc.jdemetra.org/a-outlier-detection
Examples
# Creating one or several external regressors (TS objects), which will
# be gathered in one or several groups
iv1 <- intervention_variable(12, c(2000, 1), 60,
starts = "2001-01-01", ends = "2001-12-01"
)
iv2 <- intervention_variable(12, c(2000, 1), 60,
starts = "2001-01-01", ends = "2001-12-01", delta = 1
)
# Regressors as a list of two groups reg1 and reg2
vars <- list(reg1 = list(x = iv1), reg2 = list(x = iv2), reg3 = ABS)
# Creating the modelling context
my_context <- modelling_context(variables = vars)
#> Replaced forbidden character(s) in 22 name(s).